package com.example.what_the_fantasy.ui.screens

import androidx.compose.foundation.Image
import androidx.compose.foundation.background
import androidx.compose.foundation.clickable
import androidx.compose.foundation.layout.Box
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.Spacer
import androidx.compose.foundation.layout.fillMaxHeight
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.layout.size
import androidx.compose.foundation.layout.width
import androidx.compose.runtime.Composable
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.layout.ContentScale
import androidx.compose.ui.res.painterResource
import androidx.compose.ui.unit.dp
import androidx.navigation.NavController
import androidx.navigation.compose.NavHost
import androidx.navigation.compose.composable
import androidx.navigation.compose.rememberNavController
import com.example.what_the_fantasy.R


@Composable
fun QuizAccueil(navController: NavController) {
    Row(
        modifier = Modifier
            .fillMaxSize()
            .background(Color(0xFF100C1B))
            .padding(top = 100.dp)
    ) {
        Spacer(modifier = Modifier.weight(0.1f))

        Column(
            modifier = Modifier
                .weight(0.9f)
                .fillMaxHeight(),
            horizontalAlignment = Alignment.CenterHorizontally
        ) {
            Box(
                modifier = Modifier
                    .size(width = 150.dp, height = 100.dp)
                    .padding(8.dp)
                    .clickable {
                        navController.navigate("quizPage")
                    }
            ) {
                Image(
                    painter = painterResource(id = R.drawable.quiz),
                    contentDescription = "Quiz 1",
                    modifier = Modifier.fillMaxSize(),
                    contentScale = ContentScale.Crop
                )
            }

            Box(
                modifier = Modifier
                    .size(width = 150.dp, height = 100.dp)
                    .padding(8.dp)
                    .clickable {

                        navController.navigate("quizPage")
                    }
            ) {
                Image(
                    painter = painterResource(id = R.drawable.quiz),
                    contentDescription = "Quiz 2",
                    modifier = Modifier.fillMaxSize(),
                    contentScale = ContentScale.Crop
                )
            }
        }

        Spacer(modifier = Modifier.width(10.dp))

        Column(
            modifier = Modifier
                .weight(0.9f)
                .fillMaxHeight(),
            horizontalAlignment = Alignment.CenterHorizontally
        ) {
            Box(
                modifier = Modifier
                    .size(width = 150.dp, height = 100.dp)
                    .padding(8.dp)
                    .clickable {
                        navController.navigate("quizPage")
                    }
            ) {
                Image(
                    painter = painterResource(id = R.drawable.quiz),
                    contentDescription = "Quiz 3",
                    modifier = Modifier.fillMaxSize(),
                    contentScale = ContentScale.Crop
                )
            }

            Box(
                modifier = Modifier
                    .size(width = 150.dp, height = 100.dp)
                    .padding(8.dp)
                    .clickable {
                        navController.navigate("quizPage")
                    }
            ) {
                Image(
                    painter = painterResource(id = R.drawable.quiz),
                    contentDescription = "Quiz 4",
                    modifier = Modifier.fillMaxSize(),
                    contentScale = ContentScale.Crop
                )
            }
        }

        Spacer(modifier = Modifier.weight(0.1f))
    }
}

@Composable
fun QuizApp() {
    val navController = rememberNavController()

    NavHost(navController = navController, startDestination = "quizEndPage") {
        composable("quizAccueil") {
            QuizAccueil(navController = navController)
        }
        composable("quizPage") {
            QuizPage(navController = navController)
        }
        composable("quizEndPage") {
            QuizEndPage(5, 1)
        }
    }
}