package com.example.what_the_fantasy.ui.screens

import androidx.compose.foundation.background
import androidx.compose.foundation.clickable
import androidx.compose.foundation.layout.*
import androidx.compose.foundation.shape.RoundedCornerShape
import androidx.compose.material.icons.Icons
import androidx.compose.material.icons.automirrored.filled.ArrowBack
import androidx.compose.material.icons.filled.ArrowBack
import androidx.compose.material3.Icon
import androidx.compose.material3.IconButton
import androidx.compose.material3.Text
import androidx.compose.runtime.*
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.geometry.Offset
import androidx.compose.ui.graphics.Brush
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import androidx.navigation.NavController
import com.example.what_the_fantasy.data.local.QuestionStub

@Composable
fun QuizPage(navController: NavController) {
    val questions = QuestionStub.allQuestions
    var idCurrentQuestion by remember { mutableIntStateOf(0) }
    var pts by remember { mutableIntStateOf(0) }

    val gradient = Brush.linearGradient(
        colors = listOf(Color(0xFF7B1FA2), Color(0xFF311B92)),
        start = Offset(0f, 1000f),
        end = Offset(1000f, 0f)
    )

    fun onAnswerSelected(answer: String) {
        val currentQuestion = questions[idCurrentQuestion]
        val correctAnswer = mapOf(
            "A" to currentQuestion.ansA,
            "B" to currentQuestion.ansB,
            "C" to currentQuestion.ansC,
            "D" to currentQuestion.ansD
        )[currentQuestion.correctAns]

        if (answer == correctAnswer) pts++
        if (idCurrentQuestion < questions.size - 1) idCurrentQuestion++
        else navController.popBackStack() // Retour menu
    }

    Box(
        modifier = Modifier
            .fillMaxSize()
            .background(Color(0xFF100C1B))
            .padding(16.dp)
    ) {
        Column(
            modifier = Modifier
                .fillMaxSize(),
            horizontalAlignment = Alignment.CenterHorizontally
        ) {
            val question = questions[idCurrentQuestion]

            Column (
                horizontalAlignment = Alignment.CenterHorizontally,
            ) {
                Box(
                    modifier = Modifier.fillMaxWidth()
                ) {
                    IconButton(
                        onClick = { navController.popBackStack() },
                        modifier = Modifier.align(Alignment.TopStart)
                    ) {
                        Icon(Icons.AutoMirrored.Filled.ArrowBack, contentDescription = "Retour", tint = Color.White)
                    }
                }
                Text("Question ${question.id}", color = Color.White, fontSize = 18.sp, modifier = Modifier.padding(top = 20.dp))
                Text("Points : $pts", color = Color.White, fontSize = 18.sp, modifier = Modifier.padding(top = 40.dp))
                Text(question.question, color = Color.White, fontSize = 22.sp, modifier = Modifier.padding(40.dp))
            }
            Column (
                modifier = Modifier
                    .padding(top = 30.dp)
            ) {
                listOf(question.ansA, question.ansB, question.ansC, question.ansD).forEach { answer ->
                    Box(
                        modifier = Modifier
                            .width(220.dp)
                            .height(50.dp)
                            .background(brush = gradient, shape = RoundedCornerShape(16.dp))
                            .clickable { onAnswerSelected(answer) }
                            .padding(horizontal = 8.dp),
                        contentAlignment = Alignment.Center
                    ) {
                        Text(answer, color = Color.White, fontSize = 18.sp)
                    }
                    Spacer(modifier = Modifier.height(60.dp))
                }
            }

        }
    }
}